@@ -5,7 +5,17 @@ use warnings;
 package AtteanX::Query::Cache;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.001_03';
+our $VERSION   = '0.001_04';
+use Moo;
+
+extends 'AtteanX::Endpoint';
+
+after 'log_query' => sub {
+	my $self	= shift;
+	my $req		= shift;
+	my $message	= shift;
+	$self->model->publisher->publish('analyze.fullquery', $message);
+};
 
 1;
 
