@@ -7,11 +7,12 @@ package AtteanX::Query::Cache::Analyzer::QueryPlanner;
 use Class::Method::Modifiers;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.001_03';
+our $VERSION   = '0.001_04';
 
 use Moo;
 use Attean::RDF qw(triplepattern variable iri);
 use Carp;
+use feature "state";
 
 extends 'AtteanX::QueryPlanner::Cache::LDF';
 
@@ -32,15 +33,28 @@ around 'access_plans' => sub {
 	if ($model->is_cached($keypattern)) {
 		$self->log->debug("Already accounted for by cache: $keypattern");
 	} elsif ($model->try eq $keypattern) {
-		$self->log->debug("Creating dummy table for $keypattern");
+		$self->log->debug("Creating dummy iterator for $keypattern");
 		my %row;
 		foreach my $var (@vars) {
 			$row{$var->value} = iri('urn:x-internal:dummy');
 		}
-		push(@plans, Attean::Plan::Table->new( variables => \@vars,
-															rows => [Attean::Result->new(bindings => \%row)],
-															distinct => 0,
-															ordered => [] ));
+		my $iter = Attean::CodeIterator->new(generator => sub {
+															 state $i = 0;
+															 warn $i;
+															 if ($i) {
+																 return undef
+															 } else {
+																 $i++;
+																 return Attean::Result->new(bindings => \%row);
+															 }
+														 },
+														 item_type => 'Attean::API::Result',
+														 variables => [map { $_->value } @vars]
+														);
+		push(@plans, Attean::Plan::Iterator->new( variables => \@vars,
+																iterator => $iter,
+																distinct => 0,
+																ordered => [] ));
 	}
 	return @plans;
 };
